import requests
import os
from dotenv import load_dotenv
import pandas as pd

# Load environment variables from .env file
load_dotenv()

def fetch_stock_data():
    # 직접 참조한 API 엔드포인트
    api_endpoint = 'https://api.koreainvestment.com/apiservice/real_time_data'
    api_key = os.getenv('API_KEY')

    if not api_key:
        raise ValueError("API_KEY must be set in .env file")

    headers = {
        "Authorization": f"Bearer {api_key}"
    }
    
    try:
        response = requests.get(api_endpoint, headers=headers)
        response.raise_for_status()
        data = response.json()
    except requests.exceptions.RequestException as e:
        print(f"HTTP request failed: {e}")
        return []
    except ValueError as e:
        print(f"Error parsing JSON: {e}")
        return []

    processed_data = []
    for item in data.get('items', []):
        processed_data.append({
            'date': item.get('date'),
            'price': item.get('price')
        })
    
    return processed_data

def main():
    # Fetch stock data from the API
    stock_data = fetch_stock_data()
    
    # Convert to DataFrame for further processing
    if stock_data:
        df = pd.DataFrame(stock_data)
        
        # Display DataFrame to user (or save to file)
        df.to_csv('/mnt/data/stock_data.csv', index=False)
        print("Stock data has been saved to stock_data.csv")
        import ace_tools as tools
        tools.display_dataframe_to_user(name="Stock Data", dataframe=df)
    else:
        print("No data fetched from the API")

if __name__ == "__main__":
    main()
