document.addEventListener("DOMContentLoaded", function() {
    const socket = io.connect(location.protocol + '//' + document.domain + ':' + location.port);

    socket.on('investmentAmountUpdateSuccess', function(data) {
        console.log('Success:', data);
        alert('Investment amount updated successfully');
    });

    socket.on('investmentAmountUpdateFailed', function(data) {
        console.error('Update failed:', data.error);
        alert('Error: ' + data.error);
    });

    document.getElementById('investment-amount').addEventListener('input', function(event) {
        let investmentAmount = event.target.value.replace(/,/g, '');
        if (!isNaN(investmentAmount) && investmentAmount !== '') {
            investmentAmount = parseInt(investmentAmount);
            event.target.value = formatNumberWithCommas(investmentAmount);

            socket.emit('updateInvestmentAmount', { investmentAmount: investmentAmount });
        } else {
            event.target.value = '';
        }
    });

    document.getElementById('start-trading').addEventListener('click', function() {
        socket.emit('startTrading');
        alert('자동매매가 시작되었습니다.');
    });

    document.getElementById('stop-trading').addEventListener('click', function() {
        socket.emit('stopTrading');
        alert('자동매매가 중지되었습니다.');
    });

    document.getElementById('show-chart').addEventListener('click', function() {
        fetch('/show_chart')
            .then(response => response.blob())
            .then(blob => {
                const url = URL.createObjectURL(blob);
                const chartContainer = document.getElementById('chart-container');
                const chartImage = document.getElementById('chart');
                chartImage.src = url;
                chartContainer.style.display = 'block';
            })
            .catch(error => console.error('Error:', error));
    });

    function formatNumberWithCommas(x) {
        return x.toString().replace(/\B(?=(\d{3})+(?!\d))/g, ",");
    }
});
