import gym
from stable_baselines3 import PPO
from stock_trading_env import StockTradingEnv
import pandas as pd
import logging
from stable_baselines3.common.vec_env import DummyVecEnv
from stable_baselines3.common.callbacks import EvalCallback, StopTrainingOnRewardThreshold

# Configure logging
logging.basicConfig(level=logging.INFO, format='%(asctime)s - %(levelname)s - %(message)s')

# Load historical data
df = pd.read_csv('historical_stock_data.csv')  # Example CSV file containing historical stock data

# Preprocess data (if needed)
df['Date'] = pd.to_datetime(df['Date'])
df.set_index('Date', inplace=True)
df.sort_index(inplace=True)

# Create the environment
env = DummyVecEnv([lambda: StockTradingEnv(df)])

# Create the model
model = PPO('MlpPolicy', env, verbose=1)

# Define a callback for early stopping and evaluation
eval_env = DummyVecEnv([lambda: StockTradingEnv(df)])
stop_callback = StopTrainingOnRewardThreshold(reward_threshold=10000, verbose=1)
eval_callback = EvalCallback(eval_env, callback_on_new_best=stop_callback, eval_freq=5000, best_model_save_path='./logs/', verbose=1)

# Train the model
model.learn(total_timesteps=100000, callback=eval_callback)

# Save the model
model.save("ppo_stock_trading")

# Load the model
model = PPO.load("ppo_stock_trading")

# Test the model
obs = env.reset()
for i in range(1000):
    action, _states = model.predict(obs)
    obs, rewards, done, info = env.step(action)
    if done:
        logging.info(f"Episode finished after {i+1} timesteps")
        obs = env.reset()

# Monitoring model performance
logging.info("Testing completed.")
