import matplotlib.pyplot as plt

def plot_performance(portfolio, signals):
    fig, (ax1, ax2) = plt.subplots(2, 1, figsize=(14, 10))

    # Plot price and signals
    ax1.plot(signals.index, signals['price'], label='Price')
    ax1.plot(signals.loc[signals['position'] == 1.0].index, 
             signals['price'][signals['position'] == 1.0],
             '^', markersize=10, color='g', lw=0, label='Buy Signal')
    ax1.plot(signals.loc[signals['position'] == -1.0].index, 
             signals['price'][signals['position'] == -1.0],
             'v', markersize=10, color='r', lw=0, label='Sell Signal')
    ax1.set_title('Price and Buy/Sell Signals')
    ax1.set_xlabel('Date')
    ax1.set_ylabel('Price')
    ax1.legend()

    # Plot portfolio value
    ax2.plot(portfolio.index, portfolio['total'], label='Portfolio Value')
    ax2.set_title('Portfolio Value Over Time')
    ax2.set_xlabel('Date')
    ax2.set_ylabel('Portfolio Value')
    ax2.legend()

    plt.tight_layout()
    # plt.show()  # Ensure this is commented out or removed

# Example usage within the main script
if __name__ == "__main__":
    # Load historical data
    df = pd.read_csv('historical_stock_data.csv')  # Example CSV file containing historical stock data

    # Preprocess data (if needed)
    df['Date'] = pd.to_datetime(df['Date'])
    df.set_index('Date', inplace=True)
    df.sort_index(inplace=True)

    # Create the environment
    env = DummyVecEnv([lambda: StockTradingEnv(df)])

    # Create the model
    model = PPO('MlpPolicy', env, verbose=1)

    # Define a callback for early stopping and evaluation
    eval_env = DummyVecEnv([lambda: StockTradingEnv(df)])
    stop_callback = StopTrainingOnRewardThreshold(reward_threshold=10000, verbose=1)
    eval_callback = EvalCallback(eval_env, callback_on_new_best=stop_callback, eval_freq=5000, best_model_save_path='./logs/', verbose=1)

    # Train the model
    model.learn(total_timesteps=100000, callback=eval_callback)

    # Save the model
    model.save("ppo_stock_trading")

    # Remove or comment out any plt.show() call here
    # plot_performance(portfolio, signals)  # Ensure this is commented out or removed
    # plt.show()  # Ensure this is commented out or removed
